==> jc-1.4.0.tar.gz: gnu/xml/libxmlj/dom/GnomeEntityReference.h <==
// class gnu.xml.libxmlj.dom.GnomeEntityReference

// class file dependencies
// @dep_class d45b27e3f2b1feb5 gnu_xml_libxmlj_dom_GnomeEntityReference
// @dep_class c27d1baeb6a0bacf gnu_xml_libxmlj_dom_GnomeNode
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_libxmlj_dom_GnomeNode

#include "gnu/xml/libxmlj/dom/GnomeNode.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeEntityReference_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeEntityReference_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$refs	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$object	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vtable	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vtype	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$object *, struct _jc_java_lang_Object$object *);

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vmethods {
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNode$vmethods	gnu_xml_libxmlj_dom_GnomeNode;
	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vmethods	gnu_xml_libxmlj_dom_GnomeEntityReference;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$sub_refs	gnu_xml_libxmlj_dom_GnomeEntityReference;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_refs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeEntityReference;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$object {
	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vtype _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeEntityReference, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeEntityReference_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/libxmlj/dom/GnomeEntityReference.h <==
// class gnu.xml.libxmlj.dom.GnomeEntityReference

// class file dependencies
// @dep_class d45b27e3f2b1feb5 gnu_xml_libxmlj_dom_GnomeEntityReference
// @dep_class c27d1baeb6a0bacf gnu_xml_libxmlj_dom_GnomeNode
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_libxmlj_dom_GnomeNode

#include "gnu/xml/libxmlj/dom/GnomeNode.h"

#ifndef _JC_gnu_xml_libxmlj_dom_GnomeEntityReference_H_
#define _JC_gnu_xml_libxmlj_dom_GnomeEntityReference_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$sub_refs	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$sub_refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$sub_nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$sub_nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$refs	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$refs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$nonrefs	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$nonrefs;
typedef struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$object	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$object;

typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vmethods	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vmethods;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vtable	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vtable;
typedef const struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vtype	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vtype;

// Constructors
extern void _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vmethods {
};

// Vtable
struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_libxmlj_dom_GnomeNode$vmethods	gnu_xml_libxmlj_dom_GnomeNode;
	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vmethods	gnu_xml_libxmlj_dom_GnomeEntityReference;
};

// Vtype
struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vtype {
	_jc_type			type;
	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$refs {
    _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$sub_refs	gnu_xml_libxmlj_dom_GnomeEntityReference;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_refs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_libxmlj_dom_GnomeNode$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeNode;
    _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$sub_nonrefs	gnu_xml_libxmlj_dom_GnomeEntityReference;
};

// Object instance structure
struct _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$object {
	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vtype	*vtype;
	_jc_gnu_xml_libxmlj_dom_GnomeEntityReference$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$vtype _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_libxmlj_dom_GnomeEntityReference, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_libxmlj_dom_GnomeEntityReference$class_object;

#endif	/* _JC_gnu_xml_libxmlj_dom_GnomeEntityReference_H_ */
